pub struct JitTuningModel<K> { /* private fields */ }Expand description
A more flexible but also more complex alternative to the AotTuningModel.
It allocates channels and yields detunings just-in-time and is, therefore, not dependent on any fixed tuning.
Implementations
Sourceimpl<K> JitTuningModel<K>
impl<K> JitTuningModel<K>
pub fn new( num_channels: usize, group_by: GroupBy, pooling_mode: PoolingMode, ) -> Self
Sourceimpl<K: Copy + Eq + Hash> JitTuningModel<K>
impl<K: Copy + Eq + Hash> JitTuningModel<K>
pub fn register_key(&mut self, key: K, pitch: Pitch) -> RegisterKeyResult
pub fn deregister_key(&mut self, key: K) -> AccessKeyResult
pub fn access_key(&self, key: K) -> AccessKeyResult
pub fn active_keys(&self) -> impl Iterator<Item = K> + '_